@@ -1,5 +1,5 @@
 
-from seti_python.class_read import ResponseReadCash, ResponseReadCashOut, ResponseReadPayment, ResponseReadTransactions, ResponseReadWallet, ResponseReadWalletsTransactions
+from seti_python.class_read import ResponseCreateUser, ResponseReadCash, ResponseReadCashOut, ResponseReadPayment, ResponseReadTransactions, ResponseReadWallet, ResponseReadWalletsTransactions, ResponseValidateUser
 from seti_python.wallet_class import ResponseCreateWallet
 from seti_python.class_tools import BasicResponse, CompleteBasicaResponse, ResponseCreateDispersions, ResponseCreateTransaction
 from seti_python.payment_class import ResponseCreatePayment
@@ -266,7 +266,7 @@ class Seti():
         }
         VALIDATE_USERS_EXIST = "validate-user"
         encode_data = self.sign_data(user_data)
-        return ResponseReadCashOut(self.send_request(user_data,encode_data,VALIDATE_USERS_EXIST))
+        return ResponseValidateUser(self.send_request(user_data,encode_data,VALIDATE_USERS_EXIST))
     
     def create_user(self,email:str,name:str,phone:str,iso_code:str):
         self.is_error =False
@@ -280,7 +280,7 @@ class Seti():
         }
         VALIDATE_USERS_EXIST = "create-user"
         encode_data = self.sign_data(user_data)
-        return ResponseReadCashOut(self.send_request(user_data,encode_data,VALIDATE_USERS_EXIST))
+        return ResponseCreateUser(self.send_request(user_data,encode_data,VALIDATE_USERS_EXIST))
     
 
 
